==> firefox-72.0b11.source.tar.xz: firefox-72.0/devtools/client/debugger/src/components/SecondaryPanes/Breakpoints/BreakpointHeading.js <==
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at <http://mozilla.org/MPL/2.0/>. */

// @flow
import React, { PureComponent } from "react";
import { connect } from "../../../utils/connect";
import actions from "../../../actions";
import {
  getTruncatedFileName,
  getDisplayPath,
  getSourceQueryString,
  getFileURL,
} from "../../../utils/source";
import {
  getHasSiblingOfSameName,
  getBreakpointsForSource,
  getContext,
} from "../../../selectors";

import SourceIcon from "../../shared/SourceIcon";

import type { Source, Breakpoint, Context } from "../../../types";
import showContextMenu from "./BreakpointHeadingsContextMenu";

type OwnProps = {|
  sources: Source[],
  source: Source,
|};
type Props = {
  cx: Context,
  sources: Source[],
  source: Source,
  hasSiblingOfSameName: boolean,
  breakpointsForSource: Breakpoint[],
  disableBreakpointsInSource: typeof actions.disableBreakpointsInSource,
  enableBreakpointsInSource: typeof actions.enableBreakpointsInSource,
  removeBreakpointsInSource: typeof actions.removeBreakpointsInSource,
  selectSource: typeof actions.selectSource,
};

class BreakpointHeading extends PureComponent<Props> {
  onContextMenu = (e: SyntheticEvent<HTMLElement>) => {
    showContextMenu({ ...this.props, contextMenuEvent: e });
  };

  render() {
    const {
      cx,
      sources,
      source,
      hasSiblingOfSameName,
      selectSource,
    } = this.props;

    const path = getDisplayPath(source, sources);
    const query = hasSiblingOfSameName ? getSourceQueryString(source) : "";

    return (
      <div
        className="breakpoint-heading"
        title={getFileURL(source, false)}
        onClick={() => selectSource(cx, source.id)}
        onContextMenu={this.onContextMenu}
      >
        <SourceIcon
          source={source}
          shouldHide={icon => ["file", "javascript"].includes(icon)}
        />
        <div className="filename">
          {getTruncatedFileName(source, query)}
          {path && <span>{`../${path}/..`}</span>}
        </div>
      </div>
    );
  }
}

const mapStateToProps = (state, { source }) => ({
  cx: getContext(state),
  hasSiblingOfSameName: getHasSiblingOfSameName(state, source),
  breakpointsForSource: getBreakpointsForSource(state, source.id),
});

export default connect<Props, OwnProps, _, _, _, _>(
  mapStateToProps,
  {
    selectSource: actions.selectSource,
    enableBreakpointsInSource: actions.enableBreakpointsInSource,
    disableBreakpointsInSource: actions.disableBreakpointsInSource,
    removeBreakpointsInSource: actions.removeBreakpointsInSource,
  }
)(BreakpointHeading);

==> firefox-99.0b7.source.tar.xz: firefox-99.0/devtools/client/debugger/src/components/SecondaryPanes/Breakpoints/BreakpointHeading.js <==
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at <http://mozilla.org/MPL/2.0/>. */

import React, { PureComponent } from "react";
import PropTypes from "prop-types";

import { connect } from "../../../utils/connect";
import actions from "../../../actions";

import {
  getTruncatedFileName,
  getDisplayPath,
  getSourceQueryString,
  getFileURL,
} from "../../../utils/source";
import {
  getHasSiblingOfSameName,
  getBreakpointsForSource,
  getContext,
  getThread,
} from "../../../selectors";

import SourceIcon from "../../shared/SourceIcon";

import showContextMenu from "./BreakpointHeadingsContextMenu";

class BreakpointHeading extends PureComponent {
  static get propTypes() {
    return {
      cx: PropTypes.object,
      sources: PropTypes.array,
      hasSiblingOfSameName: PropTypes.bool,
      selectSource: PropTypes.func.isRequired,
      thread: PropTypes.object,
    };
  }
  onContextMenu = e => {
    showContextMenu({ ...this.props, contextMenuEvent: e });
  };

  render() {
    const {
      cx,
      sources,
      source,
      hasSiblingOfSameName,
      selectSource,
      thread,
    } = this.props;

    const path = getDisplayPath(source, sources);
    const query = hasSiblingOfSameName ? getSourceQueryString(source) : "";

    return (
      <div
        className="breakpoint-heading"
        title={`${thread?.name} - ${getFileURL(source, false)}`}
        onClick={() => selectSource(cx, source.id)}
        onContextMenu={this.onContextMenu}
      >
        <SourceIcon
          source={source}
          modifier={icon =>
            ["file", "javascript"].includes(icon) ? null : icon
          }
        />
        <div className="filename">
          {getTruncatedFileName(source, query)}
          {path && <span>{`../${path}/..`}</span>}
        </div>
      </div>
    );
  }
}

const mapStateToProps = (state, { source }) => ({
  cx: getContext(state),
  hasSiblingOfSameName: getHasSiblingOfSameName(state, source),
  breakpointsForSource: getBreakpointsForSource(state, source.id),
  thread: getThread(state, source.thread),
});

export default connect(mapStateToProps, {
  selectSource: actions.selectSource,
  enableBreakpointsInSource: actions.enableBreakpointsInSource,
  disableBreakpointsInSource: actions.disableBreakpointsInSource,
  removeBreakpointsInSource: actions.removeBreakpointsInSource,
})(BreakpointHeading);
